class QueueNode:
    def __init__(self):
        self.data = 0
        self.next = None

class Queue:
    def __init__(self):
        return
    def enqueue(self):
        return
    def dequeue(self):
        return
    def print_queue(self):
        return