class Sorting:

    def __init__(self):
        return

    def perform_selection_sort(self):
        return

    def perform_insertion_sort(self):
        return

    def perform_heap_sort(self):
        return

    def perform_merge_sort(self):
        return

    def perform_quick_sort(self):
        return

    def perform_heap_sort(self):
        return