class LinkedNode:
    def __init__(self):
        self.data = 0
        self.next = None

class LinkedList:
    def __init__(self):
        return
    def append(self):
        return
    def insert_element(self):
        return
    def remove_element(self):
        return
    def print_list(self):
        return