class StackNode:
    def __init__(self):
        self.data = 0
        self.top = None

class Stack:
    def __init__(self):
        return
    def push(self):
        return
    def pop(self):
        return
    def print_stack(self):
        return 